==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QAbstractBarSeries_shell.h <==
#ifndef QABSTRACTBARSERIES_SHELL_H
#define QABSTRACTBARSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qabstractbarseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractBarSeries_shell : public QAbstractBarSeries, public QtJambiShellInterface
{
public:
    ~QAbstractBarSeries_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QAbstractBarSeries_mshell;
    friend class QAbstractBarSeries_oshell;
};


class QAbstractBarSeries_mshell : public QAbstractBarSeries_shell
{
public:
    using QAbstractBarSeries_shell::QAbstractBarSeries_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAbstractBarSeries_oshell : public QAbstractBarSeries_mshell
{
public:
    using QAbstractBarSeries_mshell::QAbstractBarSeries_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractBarSeries_access : public QAbstractBarSeries
{
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTBARSERIES_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiCharts/QAbstractBarSeries_shell.h <==
#ifndef QABSTRACTBARSERIES_SHELL_H
#define QABSTRACTBARSERIES_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qabstractbarseries.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractaxis.h>
#include <QtCharts/qabstractseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qchart.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QAbstractBarSeries_shell : public QAbstractBarSeries, public QtJambiShellInterface
{
public:
    ~QAbstractBarSeries_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QAbstractSeries::SeriesType type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractBarSeries_access : public QAbstractBarSeries
{
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTBARSERIES_SHELL_H
